@@ -62,6 +62,8 @@ gotoblas_t TABLE_NAME = {
  MAX(SBGEMM_DEFAULT_UNROLL_M, SBGEMM_DEFAULT_UNROLL_N),
 #endif
 
+  SBGEMM_ALIGN_K,
+
   sbstobf16_kTS, sbdtobf16_kTS, sbf16tos_kTS, dbf16tod_kTS,
 
   samax_kTS,  samin_kTS,  smax_kTS,  smin_kTS,
@@ -135,9 +137,14 @@ gotoblas_t TABLE_NAME = {
   0,
 #endif
 
-#if (BUILD_SINGLE==1 ) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
   samax_kTS,  samin_kTS,  smax_kTS,  smin_kTS,
-  isamax_kTS, isamin_kTS, ismax_kTS, ismin_kTS,
+#endif
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+  isamax_kTS,
+#endif 
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
+  isamin_kTS, ismax_kTS, ismin_kTS,
   snrm2_kTS,  sasum_kTS,
 #endif 
 #if BUILD_SINGLE == 1  
@@ -156,8 +163,10 @@ gotoblas_t TABLE_NAME = {
   sswap_kTS,
   sgemv_nTS,  sgemv_tTS,
 #endif
-#if BUILD_SINGLE == 1  
+#if BUILD_SINGLE == 1
   sger_kTS,
+#endif
+#if BUILD_SINGLE == 1  
   ssymv_LTS, ssymv_UTS,
 #endif
 
@@ -176,7 +185,7 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopyTS, sgemm_otcopyTS,
 #endif
 
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || BUILD_DOUBLE == 1 || BUILD_COMPLEX == 1
 #ifdef SMALL_MATRIX_OPT
   sgemm_small_matrix_permitTS,
   sgemm_small_kernel_nnTS, sgemm_small_kernel_ntTS, sgemm_small_kernel_tnTS, sgemm_small_kernel_ttTS,
@@ -184,7 +193,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX == 1)
   strsm_kernel_LNTS, strsm_kernel_LTTS, strsm_kernel_RNTS, strsm_kernel_RTTS,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strsm_iunucopyTS, strsm_iunncopyTS, strsm_iutucopyTS, strsm_iutncopyTS,
@@ -196,7 +205,7 @@ gotoblas_t TABLE_NAME = {
   strsm_ounucopyTS, strsm_ounncopyTS, strsm_outucopyTS, strsm_outncopyTS,
   strsm_olnucopyTS, strsm_olnncopyTS, strsm_oltucopyTS, strsm_oltncopyTS,
 #endif
-#if BUILD_SINGLE == 1
+#if (BUILD_SINGLE==1)
   strmm_kernel_RNTS, strmm_kernel_RTTS, strmm_kernel_LNTS, strmm_kernel_LTTS,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strmm_iunucopyTS, strmm_iunncopyTS, strmm_iutucopyTS, strmm_iutncopyTS,
@@ -213,8 +222,6 @@ gotoblas_t TABLE_NAME = {
   ssymm_outcopyTS, ssymm_oltcopyTS,
 #endif
   ssymm_outcopyTS, ssymm_oltcopyTS,
-#endif
-#if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)
 #ifndef NO_LAPACK
   sneg_tcopyTS, slaswp_ncopyTS,
 #else
@@ -222,7 +229,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   0, 0, 0,
   DGEMM_DEFAULT_UNROLL_M, DGEMM_DEFAULT_UNROLL_N,
 #ifdef DGEMM_DEFAULT_UNROLL_MN
@@ -233,7 +240,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   damax_kTS,  damin_kTS,  dmax_kTS,  dmin_kTS,
   idamax_kTS, idamin_kTS, idmax_kTS, idmin_kTS,
   dnrm2_kTS, dasum_kTS,
@@ -241,13 +248,13 @@ gotoblas_t TABLE_NAME = {
 #if  (BUILD_DOUBLE==1)  
   dsum_kTS,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dcopy_kTS, ddot_kTS,
 #endif
 #if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)  
   dsdot_kTS,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   drot_kTS,
   daxpy_kTS,
   dscal_kTS, 
@@ -259,7 +266,7 @@ gotoblas_t TABLE_NAME = {
   dsymv_LTS,  dsymv_UTS,
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dgemm_kernelTS, dgemm_betaTS,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dgemm_incopyTS, dgemm_itcopyTS,
@@ -269,12 +276,14 @@ gotoblas_t TABLE_NAME = {
   dgemm_oncopyTS, dgemm_otcopyTS,
 #endif
 
-#if  (BUILD_DOUBLE==1)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
 #ifdef SMALL_MATRIX_OPT
   dgemm_small_matrix_permitTS,
   dgemm_small_kernel_nnTS, dgemm_small_kernel_ntTS, dgemm_small_kernel_tnTS, dgemm_small_kernel_ttTS,
   dgemm_small_kernel_b0_nnTS, dgemm_small_kernel_b0_ntTS, dgemm_small_kernel_b0_tnTS, dgemm_small_kernel_b0_ttTS,
 #endif
+#endif
+#if  (BUILD_DOUBLE==1)   
   dtrsm_kernel_LNTS, dtrsm_kernel_LTTS, dtrsm_kernel_RNTS, dtrsm_kernel_RTTS,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopyTS, dtrsm_iunncopyTS, dtrsm_iutucopyTS, dtrsm_iutncopyTS,
@@ -364,7 +373,7 @@ gotoblas_t TABLE_NAME = {
 
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   0, 0, 0,
   CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N,
 #ifdef CGEMM_DEFAULT_UNROLL_MN
@@ -372,18 +381,23 @@ gotoblas_t TABLE_NAME = {
 #else
  MAX(CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N),
 #endif
-  camax_kTS, camin_kTS, icamax_kTS, icamin_kTS,
+#if (BUILD_COMPLEX)
+  camax_kTS, camin_kTS,
 #endif
 #if (BUILD_COMPLEX)
+  icamax_kTS, 
+#endif
+#if (BUILD_COMPLEX)
+  icamin_kTS,
   cnrm2_kTS, casum_kTS, csum_kTS,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
-  ccopy_kTS,  cdotu_kTS, cdotc_kTS,
+#if (BUILD_COMPLEX)
+  ccopy_kTS, cdotu_kTS, cdotc_kTS,
 #endif
 #if (BUILD_COMPLEX)
  csrot_kTS,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   caxpy_kTS,
   caxpyc_kTS, 
   cscal_kTS, 
@@ -397,7 +411,7 @@ gotoblas_t TABLE_NAME = {
   csymv_LTS, csymv_UTS,
   chemv_LTS, chemv_UTS, chemv_MTS, chemv_VTS,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   cgemm_kernel_nTS, cgemm_kernel_lTS, cgemm_kernel_rTS, cgemm_kernel_bTS,
   cgemm_betaTS,
 #if CGEMM_DEFAULT_UNROLL_M != CGEMM_DEFAULT_UNROLL_N
@@ -432,6 +446,7 @@ gotoblas_t TABLE_NAME = {
   ctrsm_ounucopyTS,  ctrsm_ounncopyTS,  ctrsm_outucopyTS,  ctrsm_outncopyTS,
   ctrsm_olnucopyTS,  ctrsm_olnncopyTS,  ctrsm_oltucopyTS,  ctrsm_oltncopyTS,
 #endif
+#endif
 #if (BUILD_COMPLEX)
 
   ctrmm_kernel_RNTS,  ctrmm_kernel_RTTS,  ctrmm_kernel_RRTS,  ctrmm_kernel_RCTS,
@@ -522,7 +537,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
 #ifndef NO_LAPACK
   cneg_tcopyTS,
   
@@ -866,7 +881,7 @@ gotoblas_t TABLE_NAME = {
   cgeadd_kTS,
 #endif
 #if BUILD_COMPLEX16==1
-  zgeadd_kTS
+  zgeadd_kTS,
 #endif
 };
 
@@ -878,7 +893,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX==1
@@ -891,10 +906,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_q = SBGEMM_DEFAULT_Q;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_q = SGEMM_DEFAULT_Q;
 #endif
-#if BUILD_DOUBLE== 1
+#if BUILD_DOUBLE== 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_q = DGEMM_DEFAULT_Q;
 #endif
 #if BUILD_COMPLEX== 1
@@ -907,10 +922,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_r = SBGEMM_DEFAULT_R;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_r = SGEMM_DEFAULT_R;
 #endif
-#if BUILD_DOUBLE==1 
+#if BUILD_DOUBLE==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_r = DGEMM_DEFAULT_R;
 #endif
 #if BUILD_COMPLEX==1
@@ -1313,7 +1328,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  64 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  32 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1337,7 +1352,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  96 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  48 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1361,7 +1376,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 256;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 128;
 #endif
 #if BUILD_COMPLEX==1
@@ -1385,7 +1400,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE ==1 
+#if BUILD_DOUBLE ==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1
@@ -1409,7 +1424,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  92 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE==1
+#if BUILD_DOUBLE==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  46 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1433,7 +1448,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1457,7 +1472,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1482,7 +1497,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1506,7 +1521,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1554,7 +1569,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1579,7 +1594,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 224 +  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 112 +  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX
@@ -1603,7 +1618,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1627,7 +1642,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1651,7 +1666,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1675,7 +1690,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1700,7 +1715,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1724,7 +1739,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1748,7 +1763,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1773,7 +1788,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if  (BUILD_DOUBLE==1)
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if (BUILD_COMPLEX==1)
